%==========================================================================
%
%   closestPointToPoints.m
%
%   Authors: SUMO Lab Team
%   Version: 1.0
%   Copyright: 2017
%   
%   When referring to ALBATROS please make reference to the corresponding publication:
%   
%   Van Steenkiste T., J. van der Herten, D. Deschrijver and T. Dhaene.
%   "ABLATROS: Adaptive Line-Based Sampling Trajectories for Sequential
%   Measurements". Engineering with Computers.
%
%==========================================================================
%
%   SIGNATURE:
%   [ closestPoint, closestDistance ] = closestPointToPoint( targetPoint, points, distanceFunction )
%
%==========================================================================
%
%   PURPOSE:
%   Determine the closest point to another set of points
%
%   INPUT:
%   targetPoint: point to which the closest other point will be determined
%   points: points out of which to choose the closest
%   distanceFunction: function which computes a distance between two points
%
%   OUTPUT:
%   closestPoint: the point out of points which is closest to targetPoint
%   closestDistance: the distance between the selected point and the targetPoint
%==========================================================================

function [ closestPoint, closestDistance ] = closestPointToPoint( targetPoint, points, distanceFunction )
	% any dimensionality
    closestDistance = inf;
	numPoints = size(points,1);
	for i = 1:numPoints
		point = points(i,:);
		distance = distanceFunction(targetPoint, point);
		if distance < closestDistance
			closestDistance = distance;
			closestPoint = point;
		end
	end
end

